@@ -2,7 +2,7 @@ package Net::AMQP::RabbitMQ;
 use strict;
 use warnings;
 
-our $VERSION = '1.300000';
+our $VERSION = '1.400000';
 
 use XSLoader;
 XSLoader::load "Net::AMQP::RabbitMQ", $VERSION;
@@ -64,16 +64,32 @@ C<$hostname> is the host to which a connection will be attempted.
 
 C<$options> is an optional hash respecting the following keys:
 
-     {
-       user => $user,           #default 'guest'
-       password => $password,   #default 'guest'
-       port => $port,           #default 5672
-       vhost => $vhost,         #default '/'
-       channel_max => $cmax,    #default 0
-       frame_max => $fmax,      #default 131072
-       heartbeat => $hearbeat,  #default 0
-       timeout => $seconds      #default undef (no timeout)
-     }
+    {
+        user            => $user,        #default 'guest'
+        password        => $password,    #default 'guest'
+        port            => $port,        #default 5672
+        vhost           => $vhost,       #default '/'
+        channel_max     => $cmax,        #default 0
+        frame_max       => $fmax,        #default 131072
+        heartbeat       => $hearbeat,    #default 0
+        timeout         => $seconds      #default undef (no timeout)
+
+        ssl             => 1 | 0         #default 0
+        ssl_verify_host => 1 | 0         #default 1
+        ssl_cacert      => $caert_path   #needed for ssl
+        ssl_init        => 1 | 0         #default 1, initilise the openssl library
+    }
+
+You probably don't want to touch C<ssl_init>, unless you know what it does.
+
+For now there is no option to disable ssl peer checking, meaning to use C<ssl>, C<ssl_cacert> is required.
+
+B<SSL NOTE>
+
+if the connection is cut when using ssl, openssl will throw a C<SIGPIPE>, you should catch this or perl
+will exit with error code 141
+
+    $SIG{PIPE} = 'IGNORE';
 
 =head2 disconnect()
 
@@ -135,7 +151,6 @@ C<$options> is an optional hash respecting the following keys:
 
      {
        if_unused => $boolean,   #default 1
-       nowait => $boolean,      #default 0
      }
 
 =head2 exchange_bind($channel, $destination, $source, $routing_key, $arguments)
